==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/emrcontainers/kotlin/outputs/JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emrcontainers.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property cloudWatchMonitoringConfiguration Monitoring configurations for CloudWatch.
 * @property persistentAppUi Monitoring configurations for the persistent application UI.
 * @property s3MonitoringConfiguration Amazon S3 configuration for monitoring log publishing.
 */
public data class JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration(
    public val cloudWatchMonitoringConfiguration:
    JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfigurationCloudWatchMonitoringConfiguration? =
        null,
    public val persistentAppUi: String? = null,
    public val s3MonitoringConfiguration:
    JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfigurationS3MonitoringConfiguration? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.emrcontainers.outputs.JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration):
            JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration =
            JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration(
                cloudWatchMonitoringConfiguration = javaType.cloudWatchMonitoringConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.emrcontainers.kotlin.outputs.JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfigurationCloudWatchMonitoringConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                persistentAppUi = javaType.persistentAppUi().map({ args0 -> args0 }).orElse(null),
                s3MonitoringConfiguration = javaType.s3MonitoringConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.emrcontainers.kotlin.outputs.JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfigurationS3MonitoringConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/emrcontainers/kotlin/outputs/JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emrcontainers.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property cloudWatchMonitoringConfiguration Monitoring configurations for CloudWatch.
 * @property persistentAppUi Monitoring configurations for the persistent application UI.
 * @property s3MonitoringConfiguration Amazon S3 configuration for monitoring log publishing.
 */
public data class JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration(
    public val cloudWatchMonitoringConfiguration: JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfigurationCloudWatchMonitoringConfiguration? =
        null,
    public val persistentAppUi: String? = null,
    public val s3MonitoringConfiguration: JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfigurationS3MonitoringConfiguration? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.emrcontainers.outputs.JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration): JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration =
            JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration(
                cloudWatchMonitoringConfiguration = javaType.cloudWatchMonitoringConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.emrcontainers.kotlin.outputs.JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfigurationCloudWatchMonitoringConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                persistentAppUi = javaType.persistentAppUi().map({ args0 -> args0 }).orElse(null),
                s3MonitoringConfiguration = javaType.s3MonitoringConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.emrcontainers.kotlin.outputs.JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfigurationS3MonitoringConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
